@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -423,10 +423,6 @@ public class Datamining {
                 jdbcProps.setProperty("socketTimeout", "15000");
             }
             jdbcProps.setProperty("useSSL", "false");
-            jdbcProps.setProperty("requireSSL", "false");
-            jdbcProps.setProperty("verifyServerCertificate", "false");
-            jdbcProps.setProperty("enabledTLSProtocols", "TLSv1,TLSv1.1,TLSv1.2");
-            jdbcProps.setProperty("nullCatalogMeansCurrent", "true");
 
             in = new FileInputStream("/opt/open-xchange/etc/dbconnector.yaml");
             Yaml yaml = new Yaml(new SafeConstructor());
